@@ -33,6 +33,33 @@ $('<link>')
         href: local_uri_prefix + 'css/kismet.ui.base.css'
     });
 
+/* Call from index to set the required ajax parameters universally */
+exports.ConfigureAjax = function() {
+    $.ajaxSetup({
+        beforeSend: function (xhr) {
+            var user = kismet.getStorage('kismet.base.login.username', 'kismet');
+            var pw =  kismet.getStorage('kismet.base.login.password', '');
+
+            xhr.setRequestHeader ("Authorization", "Basic " + btoa(user + ":" + pw));
+        },
+
+        /*
+        dataFilter: function(data, type) {
+            try {
+                var json = JSON.parse(data);
+                var sjson = kismet.sanitizeObject(json);
+                console.log(JSON.stringify(sjson));
+                return JSON.stringify(sjson);
+            } catch {
+                return data;
+            }
+        },
+        */
+    });
+}
+
+exports.ConfigureAjax();
+
 /* Define some callback functions for the table */
 
 exports.renderLastTime = function(data, type, row, meta) {
@@ -69,6 +96,30 @@ exports.renderPackets = function(data, type, row, meta) {
     return "<i>Preparing graph</i>";
 }
 
+exports.renderUsecTime = function(data, type, row, meta) {
+    if (data == 0)
+        return "<i>n/a</i>";
+
+    var data_sec = data / 1000000;
+
+    var days = Math.floor(data_sec / 86400);
+    var hours = Math.floor((data_sec / 3600) % 24);
+    var minutes = Math.floor((data_sec / 60) % 60);
+    var seconds = Math.floor(data_sec % 60);
+
+    var ret = "";
+
+    if (days > 0)
+        ret = ret + days + "d ";
+    if (hours > 0 || days > 0)
+        ret = ret + hours + "h ";
+    if (minutes > 0 || hours > 0 || days > 0)
+        ret = ret + minutes + "m ";
+    ret = ret + seconds + "s";
+
+    return ret;
+}
+
 exports.drawPackets = function(dyncolumn, table, row) {
     // Find the column
     var rid = table.column(dyncolumn.name + ':name').index();
@@ -977,6 +1028,7 @@ function memorydisplay_refresh() {
 
     $.get(local_uri_prefix + "system/status.json")
     .done(function(data) {
+        console.log(data);
         // Common rrd type and source field
         var rrdtype = kismet.RRD_MINUTE;
         var rrddata = 'kismet.common.rrd.hour_vec';
